@@ -4,7 +4,6 @@
 // The generic remote controller.
 
 #include <QObject>
-//#include <QMutex>
 #include "pirkeynames.h"
 
 #include <map>
@@ -85,6 +84,13 @@ public:
     unsigned int secondAddress,
     unsigned int secondCommand);
 
+/*
+  void addRCAKey(
+    PIRKeyName key,
+    unsigned int addressData,
+    unsigned int commandData);
+*/
+
   void setCarrierFrequency(
     unsigned int freq);
 
